pub fn spawn(cmd: &str) -> ChildProcessExpand description
Spawns a new child process running cmd with no arguments, returning a
handle to the resulting ChildProcess.
pub fn spawn(cmd: &str) -> ChildProcessSpawns a new child process running cmd with no arguments, returning a
handle to the resulting ChildProcess.