spawn_with_args_and_options

Function spawn_with_args_and_options 

pub fn spawn_with_args_and_options(
    cmd: &str,
    args: &SpawnArgs,
    options: &SpawnOptions,
) -> ChildProcess
Spawns a new child process running cmd with the given args and options, returning a handle to the resulting ChildProcess.