readdir

Function readdir 

pub async fn readdir(path: &str) -> Result<JsValue, JsValue>
Asynchronously reads the contents of the directory at path, returning an array of the names of the entries it contains.