write_file_sync

Function write_file_sync 

pub fn write_file_sync(
    path: &str,
    data: JsValue,
    options: Object,
) -> Result<(), JsValue>
Synchronously writes data to the file at path, creating or replacing it according to the supplied options (e.g. encoding, mode, flag).