Module process

Module process 

Module encapsulating Process API for running child process daemons under Node.js and NWJS

Structs

ExecutionResult
Child process execution result
Options
Options for Process daemon runner
Process
The Process class facilitating execution of a Child Process in Node.js or NWJS environments. This wrapper runs the child process as a daemon, restarting it if it fails. The process provides stdout and stderr output as channel Receiver channels, allowing for a passive capture of the process console output.
Version
Version struct for standard version extraction from executables via --version output

Enums

Event
Event emitted by a running Process and relayed over its event channel.
Termination
Describes how a child process execution ended.

Functions

exec
Execute the process single time with custom command-line arguments. Useful to obtain a version via --version or perform single-task executions - not as a daemon.
test_child_process
Manual test harness that spawns and runs a sample child process daemon.
trim
Strips a single trailing newline (\n or \r\n) from the given string.
version
Obtain the process version information by running it with --version argument.