pub enum Event {
Start,
Exit(u32),
Error(String),
Stdout(String),
Stderr(String),
}Expand description
Event emitted by a running Process and relayed over its event channel.
Variants
Start
The child process has started.
Exit(u32)
The child process exited gracefully with the given exit code.
Error(String)
The child process terminated with an error described by the message.
Stdout(String)
A line of standard output emitted by the child process.
Stderr(String)
A line of standard error emitted by the child process.