Bindings to the Node.js child_process module for spawning child processes.
Structs
- Child
Process - Handle to a spawned child process (Node.js
ChildProcess), anEventEmitterexposing its streams and lifecycle. - Cp
- Binding to the Node.js
child_processmodule, used to spawn child processes. - Spawn
Args - JavaScript array of command-line arguments passed to a spawned process.
- Spawn
Options - JavaScript options object (cwd, env, stdio, …) for spawning a process.
Enums
- Kill
Signal - Signal to send to a child process when terminating it via
ChildProcess::kill_with_signal.
Functions
- spawn
- Spawns a new child process running
cmdwith no arguments, returning a handle to the resultingChildProcess. - spawn_
with_ args - Spawns a new child process running
cmdwith the givenargs, returning a handle to the resultingChildProcess. - spawn_
with_ args_ and_ options - Spawns a new child process running
cmdwith the givenargsandoptions, returning a handle to the resultingChildProcess.