pub fn read_file_sync(path: &str, options: Object) -> Result<JsValue, JsValue>Expand description
Synchronously reads and returns the contents of the file at path. The
returned value is a Buffer, or a string when an encoding is given in
options.