Module workflow_node::process
source · Expand description
Module encapsulating Process API for running child process daemons under Node.js and NWJS
Structs
- Child process execution result
- Options for
Processdaemon runner - The
Processclass facilitating execution of a Child Process in Node.js or NWJS environments. This wrapper runs the child process as a daemon, restarting it if it fails. The process providesstdoutandstderroutput as channelReceiverchannels, allowing for a passive capture of the process console output. - Version struct for standard version extraction from executables via
--versionoutput