Module workflow_node::process

source ·
Module encapsulating Process API for running child process daemons under Node.js and NWJS

Structs

  • Child process execution result
  • Options for Process daemon runner
  • The Process class facilitating execution of a Child Process in Node.js or NWJS environments. This wrapper runs the child process as a daemon, restarting it if it fails. The process provides stdout and stderr output as channel Receiver channels, allowing for a passive capture of the process console output.
  • Version struct for standard version extraction from executables via --version output

Functions